@@ -1,7 +1,7 @@
 /****************************************************************************
  *
- * Copyright (c) 1996-2020 Vladi Belperchinov-Shabanski "Cade" 
- * http://cade.datamax.bg/  <cade@biscom.net> <cade@bis.bg> <cade@datamax.bg>
+ * Copyright (c) 1996-2021 Vladi Belperchinov-Shabanski "Cade" 
+ * http://cade.noxrun.com/  <cade@noxrun.com> <cade@bis.bg>
  *
  * SEE `README',`LICENSE' OR `COPYING' FILE FOR LICENSE AND OTHER DETAILS!
  *
@@ -85,7 +85,7 @@
 #endif
 
   typedef double fsize_t; /* used as big integer */
-  typedef char  max_path_str_t[MAX_PATH]; /* */
+  typedef char  fname_t[MAX_PATH]; /* */
 
 /*############################################ GLOBAL DEFINES  #########*/
 
