@@ -1,7 +1,7 @@
 /****************************************************************************
  *
- * Copyright (c) 1996-2020 Vladi Belperchinov-Shabanski "Cade" 
- * http://cade.datamax.bg/  <cade@biscom.net> <cade@bis.bg> <cade@datamax.bg>
+ * Copyright (c) 1996-2021 Vladi Belperchinov-Shabanski "Cade" 
+ * http://cade.noxrun.com/  <cade@noxrun.com> <cade@bis.bg>
  *
  * SEE `README',`LICENSE' OR `COPYING' FILE FOR LICENSE AND OTHER DETAILS!
  *
@@ -223,11 +223,13 @@ void vfu_read_files( int a_recursive )
     {
     ASSERT( work_mode == WM_NORMAL );
     vfu_read_external_files();
+    opt.sort_order = 'U';
     } else
   if ( list_panelizer.count()  )
     {
     ASSERT( work_mode == WM_NORMAL );
     vfu_read_pszlist_files();
+    opt.sort_order = 'U';
     }
   else
     {
@@ -285,7 +287,7 @@ int vfu_add_file( const char* fname, const struct stat *st, int is_link )
     if ( is_link )
       {
       /* symlinks */
-      char t[MAX_PATH];
+      fname_t t;
       expand_path( fi->full_name( 1 ), t );
       str_fix_path( t );
       fi->set_size( size_cache_get( t ) );
@@ -374,35 +376,22 @@ void vfu_read_local_files( int a_recursive )
 
 void vfu_read_external_files()
 {
-  /* FIXME: this is not completely correct: lines read are in most
-     cases far less in length that MAX_PATH which is about 2-4K so
-     in general case this will work fine... */
-  char tmp[MAX_PATH];
-  char tmp1[MAX_PATH];
+  fname_t fn_line;
 
   if ( external_panelizer == "" ) return;
   say1( "Rescanning files...(external panelizer)" );
   FILE *f = popen( external_panelizer, "r" );
-  while( fgets( tmp, MAX_PATH-1, f ) )
+  while( fgets( fn_line, MAX_PATH - 1, f ) )
     {
-    str_cut( tmp, " \t\n\r" );
+    str_cut( fn_line, " \t\n\r" );
+    if ( access( fn_line, F_OK ) ) continue;
 
-    while( str_word( tmp, " \t:;", tmp1 ) )
-      {
-      if ( access( tmp1, F_OK ) ) continue;
+    struct stat st;
+    stat( fn_line, &st );
 
-      struct stat st;
-      stat( tmp1, &st );
+    say2( fn_line );
 
-      say2( tmp1 );
-
-      if ( vfu_add_file( tmp1, &st, file_is_link( tmp1 ) ) )
-        {
-        pclose( f );
-        external_panelizer = ""; /* reset -- there's no reload on this */
-        return;
-        }
-      }
+    vfu_add_file( fn_line, &st, file_is_link( fn_line ) );
     }
   pclose( f );
   external_panelizer = ""; /* reset -- there's no reload on this */
@@ -565,6 +554,7 @@ void __vfu_sort( int l, int r )
 void vfu_sort_files()
 {
   if ( ! files_list_cnt ) return;
+  if ( opt.sort_order == 'U' ) return;
   VString str = files_list[FLI]->name();
 
   VString ss = "Sorting... [";
@@ -601,7 +591,7 @@ void vfu_arrange_files()
   mb.push( "T Modify Time" );
   mb.push( "H Change Time" );
   mb.push( "C Access Time" );
-  mb.push( "A Attr/mode" );
+  mb.push( "D Attr/mode" );
   mb.push( "O Owner" );
   mb.push( "G Group" );
   mb.push( "Y Type (TP)" );
@@ -610,10 +600,18 @@ void vfu_arrange_files()
   mb.push( "R Randomize" );
   mb.push( "V Move Entry" );
   mb.push( "---" );
-  mb.push( "D Modify Time (compat)" );
+  mb.push( "A Quick swap NAME/CHANGE" );
   if ( vfu_menu_box( 50, 5, "Arrange" ) == -1 ) return;
   _ord = menu_box_info.ec;
-  if ( _ord == 'D' ) _ord = 'T';
+
+  if ( _ord == 'A' )
+    {
+    opt.sort_direction = 'A';
+    opt.sort_order = opt.sort_order == 'N' ? 'H' : 'N';
+    vfu_sort_files();
+    say1( VString( "File list is now arranged by " ) + ( opt.sort_order == 'N' ? "NAME (ASCENDING)" : "CHANGE TIME (ASCENDING)" ) );
+    return;
+    }
 
   if (_ord == 'V' )
     {
@@ -637,13 +635,20 @@ void vfu_arrange_files()
     return;
     }
 
+  opt.sort_order = _ord;
+  
+  if( opt.sort_order == 'U' ) 
+    {
+    say1( "Next directory rescan will be unsorted." );
+    return;
+    }
+
   mb.undef();
   mb.push( "A Ascending");
   mb.push( "D Descending" );
   if ( vfu_menu_box( 50, 5, "Order" ) == -1 ) return;
   _rev = menu_box_info.ec;
 
-  opt.sort_order = _ord;
   opt.sort_direction = _rev;
 
   vfu_sort_files();
