@@ -1,11 +1,11 @@
-/*
+/****************************************************************************
  *
- *  (c) Vladi Belperchinov-Shabanski "Cade" 1996-2012
- *  http://cade.datamax.bg/  <cade@biscom.net> <cade@bis.bg> <cade@datamax.bg>
+ * Copyright (c) 1996-2020 Vladi Belperchinov-Shabanski "Cade" 
+ * http://cade.datamax.bg/  <cade@biscom.net> <cade@bis.bg> <cade@datamax.bg>
  *
  * SEE `README',`LICENSE' OR `COPYING' FILE FOR LICENSE AND OTHER DETAILS!
  *
- */
+ ****************************************************************************/
 
 #include <assert.h>
 
@@ -119,7 +119,7 @@
     if ( _pos  < _page ) return 0;
     if ( _pagesize < 0 ) return 0;
     if ( _pagestep < 1 ) return 0;
-    if ( _pos >= _page + _pagesize ) return 0;
+//    if ( _pos >= _page + _pagesize ) return 0;
     return 1;
   }
 
