@@ -1,11 +1,11 @@
-/*
+/****************************************************************************
  *
- *  (c) Vladi Belperchinov-Shabanski "Cade" 1996-2012
- *  http://cade.datamax.bg/  <cade@biscom.net> <cade@bis.bg> <cade@datamax.bg>
+ * Copyright (c) 1996-2020 Vladi Belperchinov-Shabanski "Cade" 
+ * http://cade.datamax.bg/  <cade@biscom.net> <cade@bis.bg> <cade@datamax.bg>
  *
  * SEE `README',`LICENSE' OR `COPYING' FILE FOR LICENSE AND OTHER DETAILS!
  *
- */
+ ****************************************************************************/
 
 #include "unicon.h"
 
@@ -45,6 +45,7 @@
 
   void con_suspend() { return; }
   void con_restore() { return; }
+  void con_reset_screen_size() { return; }
 
   void con_ce( int attr )
   {
@@ -87,13 +88,13 @@
     #endif
   }
 
-  int con_max_x() { return ti.screenwidth; }
+  int con_max_x() { return ti.screenwidth;  }
   int con_max_y() { return ti.screenheight; }
   int con_x() { return wherex(); }
   int con_y() { return wherey(); }
   void con_fg( int color ) { __fg = color; __ta = CONCOLOR(__fg,__bg); textattr( __ta ); }
   void con_bg( int color ) { __bg = color; __ta = CONCOLOR(__fg,__bg); textattr( __ta ); }
-  void con_ta( int attr ) { __ta = attr; __bg = COLORBG(attr); __fg = COLORFG(attr); textattr( attr ); }
+  void con_ta( int attr  ) { __ta = attr;  __bg = COLORBG(attr); __fg = COLORFG(attr); textattr( attr ); }
   void con_xy( int x, int y ) { gotoxy( x, y ); }
 
   void con_chide() { _setcursortype( _NOCURSOR ); }
@@ -124,7 +125,7 @@
 **
 ****************************************************************************/
 
-#ifdef _TARGET_UNIX_
+#ifdef _TARGET_HAVE_CURSES
 
 /****************************************************************************
 ** This part is loosely based on `linconio':
@@ -187,6 +188,7 @@
     // intrflush(conio_scr,FALSE); //
     idlok(conio_scr,TRUE);      // hardware line ins/del (required?)
     idcok(conio_scr,TRUE);      // hardware char ins/del (required?)
+    // nodelay(conio_scr,FALSE);   // blocking getch()
     scrollok(conio_scr,TRUE);   // scroll screen if required (cursor at bottom)
     /* Color initialization */
     for ( __bg=0; __bg<8; __bg++ )
@@ -212,6 +214,12 @@
     con_init();
   }
 
+  void con_reset_screen_size()
+  {
+    //ungetch( KEY_RESIZE );
+    //nodelay(conio_scr,TRUE);   // non-blocking getch()
+  }
+
   void con_ta( int attr )
   {
     __ta = attr;
@@ -266,34 +274,22 @@
 
   int con_max_x()
   {
-    int x;
-    int y;
-    getmaxyx(conio_scr,y,x);
-    return(x);
+    return getmaxx(conio_scr);
   }
 
   int con_max_y()
   {
-    int x;
-    int y;
-    getmaxyx(conio_scr,y,x);
-    return(y);
+    return getmaxy(conio_scr);
   }
 
   int con_x()
   {
-    int y;
-    int x;
-    getyx(conio_scr,y,x);
-    return(x+1);
+    return getcurx(conio_scr)+1;
   }
 
   int con_y()
   {
-    int y;
-    int x;
-    getyx(conio_scr,y,x);
-    return(y+1);
+    return getcury(conio_scr)+1;
   }
 
   void con_fg( int color )
@@ -361,7 +357,218 @@
     fflush( stdout );
   }
 
-#endif /* _TARGET_UNIX_ */
+#endif /* _TARGET_HAVE_CURSES */
+
+// target have yascreen curses replacement
+#ifdef _TARGET_HAVE_YASCREEN
+#include <stdio.h>
+#include <signal.h>
+
+  int __fg;
+  int __bg;
+  int __ta;
+  int __x=0;
+  int __y=0;
+  uint32_t __attr=0;
+  yascreen *ya_s=NULL;
+
+  /* Some internals... */
+  int colortab(int a) /* convert UNIX/Curses Color code to DOS-standard */
+  {
+     switch(a) {
+        case cBLACK   : return YAS_BLACK;
+        case cBLUE    : return YAS_BLUE;
+        case cGREEN   : return YAS_GREEN;
+        case cCYAN    : return YAS_CYAN;
+        case cRED     : return YAS_RED;
+        case cMAGENTA : return YAS_MAGENTA;
+        case cYELLOW  : return YAS_YELLOW;
+        case cWHITE   : return YAS_WHITE;
+     }
+     return 0;
+  }
+
+  void con_yas_sigwinch( int sig )
+  {
+    signal( SIGWINCH, con_yas_sigwinch ); // (re)setup signal handler
+    con_reset_screen_size();
+  }
+
+  int con_init()
+  {
+    signal( SIGWINCH, con_yas_sigwinch ); // (re)setup signal handler
+    if (ya_s)
+    {
+      yascreen_term_set(ya_s,YAS_NOBUFF|YAS_NOSIGN|YAS_NOECHO);
+      if (-1==yascreen_resize(ya_s,0,0))
+        yascreen_resize(ya_s,80,25);
+      yascreen_altbuf(ya_s,1);
+      yascreen_cursor(ya_s,0);
+      con_ta(7);
+      yascreen_redraw(ya_s);
+      return 0;
+    }
+    ya_s=yascreen_init(0,0);
+    if (!ya_s)
+      ya_s=yascreen_init(80,25);
+    if (!ya_s)
+    return 1;
+    yascreen_term_set(ya_s,YAS_NOBUFF|YAS_NOSIGN|YAS_NOECHO);
+    yascreen_altbuf(ya_s,1);
+    yascreen_cursor(ya_s,0);
+    con_ta(7);
+    return 0;
+  }
+
+  void con_done()
+  {
+    yascreen_clear(ya_s);
+    yascreen_altbuf(ya_s,0);
+    yascreen_cursor(ya_s,1);
+    yascreen_term_restore(ya_s);
+    yascreen_free(ya_s);
+    ya_s=NULL;
+  }
+
+  void con_suspend()
+  {
+    con_done();
+  }
+
+  void con_restore()
+  {
+    con_init();
+    yascreen_update(ya_s);
+  }
+
+  void con_reset_screen_size()
+  {
+    yascreen_pushch(ya_s,YAS_SCREEN_SIZE);
+  }
+
+  void con_ta( int attr )
+  {
+    __ta = attr;
+    __fg = COLORFG(attr);
+    __bg = COLORBG(attr);
+    __attr = YAS_FGCOLOR(colortab(__fg%8))|YAS_BGCOLOR(colortab(__bg%8))|((__bg>7)*YAS_ITALIC)|((__fg>7)*YAS_BOLD);
+  }
+
+  void con_ce( int attr )
+  {
+    if (attr != -1)
+      {
+      int ta = __ta;
+      con_ta( attr );
+      yascreen_printxyu(ya_s,__x,__y,__attr,"%*s",yascreen_sx(ya_s),"");
+      con_ta( ta );
+      }
+    else
+      {
+      yascreen_printxyu(ya_s,__x,__y,__attr,"%*s",yascreen_sx(ya_s),"");
+      }
+  }
+
+  void con_cs( int attr )
+  {
+    if (attr != -1)
+      {
+      int ta = __ta;
+      con_ta( attr );
+      yascreen_clear_mem(ya_s,__attr);
+      __x=__y=0;
+      yascreen_update(ya_s);
+      con_ta( ta );
+      }
+    else
+      {
+      yascreen_clear_mem(ya_s,__attr);
+      __x=__y=0;
+      yascreen_update(ya_s);
+      }
+  }
+
+  void con_puts( const char *s )
+  {
+    yascreen_putsxyu(ya_s,__x,__y,__attr,s);
+    __x=yascreen_x(ya_s);
+    __y=yascreen_y(ya_s);
+  }
+
+  int con_max_x()
+  {
+    return yascreen_sx(ya_s);
+  }
+
+  int con_max_y()
+  {
+    return yascreen_sy(ya_s);
+  }
+
+  int con_x()
+  {
+    return(__x+1);
+  }
+
+  int con_y()
+  {
+    return(__y+1);
+  }
+
+  void con_fg( int color )
+  {
+    __fg=color;
+    con_ta( CONCOLOR( __fg, __bg ) );
+  }
+
+  void con_bg( int color )
+  {
+    __bg=color;
+    con_ta( CONCOLOR( __fg, __bg ) );
+  }
+
+
+  void con_xy( int x, int y )
+  {
+    __x=x-1;
+    __y=y-1;
+    yascreen_cursor_xy(ya_s,__x,__y);
+  }
+
+  void con_chide()
+  {
+    con_xy( 1, 1 );
+    yascreen_cursor(ya_s,0);
+  }
+
+  void con_cshow()
+  {
+    yascreen_cursor(ya_s,1);
+  }
+
+  int con_kbhit()
+  {
+    int i=yascreen_peekch(ya_s);
+
+    if (i==-1)
+      i=0;
+    return(i);
+  }
+
+  int con_getch()
+  {
+    int i;
+    i=yascreen_getch(ya_s);
+    if (i==-1) i=0;
+    return(i);
+  }
+
+  void con_beep()
+  {
+    printf( "\007" );
+    fflush( stdout );
+  }
+#endif
 
 /****************************************************************************
 **
