@@ -1,15 +1,19 @@
-/*
+/****************************************************************************
  *
- * (c) Vladi Belperchinov-Shabanski "Cade" 1996-2012
+ * Copyright (c) 1996-2020 Vladi Belperchinov-Shabanski "Cade" 
  * http://cade.datamax.bg/  <cade@biscom.net> <cade@bis.bg> <cade@datamax.bg>
  *
  * SEE `README',`LICENSE' OR `COPYING' FILE FOR LICENSE AND OTHER DETAILS!
  *
- */
+ ****************************************************************************/
 
 #ifndef _UNICON_H_
 #define _UNICON_H_
 
+#ifdef HAVE_CONFIG_H
+  #include "config.h"
+#endif
+
 #include "target.h"
 
 #ifdef _TARGET_UNKNOWN_
@@ -17,12 +21,37 @@
 #endif
 
 #ifdef _TARGET_UNIX_
-  #if defined(_TARGET_LINUX_)
-  #include <curses.h>
-  #elif defined(_TARGET_NETBSD_)
-  #include <ncurses.h>
+  #ifdef _TARGET_HAVE_YASCREEN
+    #define inline
+    #include <yascreen.h>
+    #undef inline
   #else
-  #include <curses.h>
+    #if HAVE_CONFIG_H
+      // This will find the curses header on most systems. If it isn't found,
+      // the user will receive an error and compilation will terminate.
+      // These are defined when ../configure is run, and suggested use is
+      // mentioned in the autoconf documentation
+      // <https://www.gnu.org/software/autoconf-archive/ax_with_curses.html>
+      #if defined HAVE_NCURSESW_CURSES_H
+      #  include <ncursesw/curses.h>
+      #elif defined HAVE_NCURSESW_H
+      #  include <ncursesw.h>
+      #elif defined HAVE_NCURSES_CURSES_H
+      #  include <ncurses/curses.h>
+      #elif defined HAVE_NCURSES_H
+      #  include <ncurses.h>
+      #elif defined HAVE_CURSES_H
+      #  include <curses.h>
+      #else
+      #  error "SysV or X/Open-compatible Curses header file required"
+      #endif
+    #elif defined(_TARGET_LINUX_)
+    #include <curses.h>
+    #elif defined(_TARGET_NETBSD_)
+    #include <ncurses.h>
+    #else
+    #include <curses.h>
+    #endif
   #endif
   #include <stdlib.h>
 #endif
@@ -213,11 +242,9 @@
   #define KEY_ALT_N     (KEY_PREFIX + 49)
   #define KEY_ALT_M     (KEY_PREFIX + 50)
 
-#endif
-
 /******* UNIX/NCURSES ******************************************************/
 
-#ifdef _TARGET_UNIX_
+#elif defined(_TARGET_HAVE_CURSES)
 
   #define KEY_F1        (KEY_F(0) + 1)
   #define KEY_F2        (KEY_F(0) + 2)
@@ -276,6 +303,7 @@
   #define KEY_ALT_0     (KEY_PREFIX + '0')
   #define KEY_ALT_MINUS (KEY_PREFIX + '-')
   #define KEY_ALT_EQ    (KEY_PREFIX + '=')
+  #define KEY_ALT_BACKSPACE (KEY_PREFIX + KEY_BACKSPACE )
 
   #define KEY_ALT_Q     (KEY_PREFIX + 'q')
   #define KEY_ALT_W     (KEY_PREFIX + 'w')
@@ -306,6 +334,101 @@
   #define KEY_ALT_N     (KEY_PREFIX + 'n')
   #define KEY_ALT_M     (KEY_PREFIX + 'm')
 
+#elif defined(_TARGET_HAVE_YASCREEN)
+
+  #define KEY_IC YAS_K_INS
+  #define KEY_BACKSPACE YAS_K_BSP
+  #define KEY_LEFT YAS_K_LEFT
+  #define KEY_RIGHT YAS_K_RIGHT
+  #define KEY_UP YAS_K_UP
+  #define KEY_DOWN YAS_K_DOWN
+  #define KEY_HOME YAS_K_HOME
+  #define KEY_END YAS_K_END
+  #define KEY_DC YAS_K_DEL
+  #define KEY_PPAGE YAS_K_PGUP
+  #define KEY_NPAGE YAS_K_PGDN
+
+  #define KEY_ALT_A YAS_K_ALT('a')
+  #define KEY_ALT_B YAS_K_ALT('b')
+  #define KEY_ALT_C YAS_K_ALT('c')
+  #define KEY_ALT_D YAS_K_ALT('d')
+  #define KEY_ALT_E YAS_K_ALT('e')
+  #define KEY_ALT_F YAS_K_ALT('f')
+  #define KEY_ALT_G YAS_K_ALT('g')
+  #define KEY_ALT_H YAS_K_ALT('h')
+  #define KEY_ALT_I YAS_K_ALT('i')
+  #define KEY_ALT_J YAS_K_ALT('j')
+  #define KEY_ALT_K YAS_K_ALT('k')
+  #define KEY_ALT_L YAS_K_ALT('l')
+  #define KEY_ALT_M YAS_K_ALT('m')
+  #define KEY_ALT_N YAS_K_ALT('n')
+  #define KEY_ALT_R YAS_K_ALT('r')
+  #define KEY_ALT_S YAS_K_ALT('s')
+  #define KEY_ALT_X YAS_K_ALT('x')
+  #define KEY_ALT_Z YAS_K_ALT('z')
+  #define KEY_ALT_0 YAS_K_ALT('0')
+  #define KEY_ALT_1 YAS_K_ALT('1')
+  #define KEY_ALT_2 YAS_K_ALT('2')
+  #define KEY_ALT_3 YAS_K_ALT('3')
+  #define KEY_ALT_4 YAS_K_ALT('4')
+  #define KEY_ALT_5 YAS_K_ALT('5')
+  #define KEY_ALT_6 YAS_K_ALT('6')
+  #define KEY_ALT_7 YAS_K_ALT('7')
+  #define KEY_ALT_8 YAS_K_ALT('8')
+  #define KEY_ALT_9 YAS_K_ALT('9')
+  #define KEY_ALT_EQ YAS_K_ALT('=')
+  #define KEY_ALT_MINUS YAS_K_ALT('-')
+  #define KEY_ALT_BACKSPACE YAS_K_ALT( KEY_BACKSPACE )
+
+  #define KEY_F1 YAS_K_F1
+  #define KEY_F2 YAS_K_F2
+  #define KEY_F3 YAS_K_F3
+  #define KEY_F4 YAS_K_F4
+  #define KEY_F5 YAS_K_F5
+  #define KEY_F6 YAS_K_F6
+  #define KEY_F7 YAS_K_F7
+  #define KEY_F8 YAS_K_F8
+  #define KEY_F9 YAS_K_F9
+  #define KEY_F10 YAS_K_F10
+
+  #define KEY_SH_F1 YAS_K_S_F1
+  #define KEY_SH_F2 YAS_K_S_F2
+  #define KEY_SH_F3 YAS_K_S_F3
+  #define KEY_SH_F4 YAS_K_S_F4
+  #define KEY_SH_F5 YAS_K_S_F5
+  #define KEY_SH_F6 YAS_K_S_F6
+  #define KEY_SH_F7 YAS_K_S_F7
+  #define KEY_SH_F8 YAS_K_S_F8
+  #define KEY_SH_F9 YAS_K_S_F9
+  #define KEY_SH_F10 YAS_K_S_F10
+
+  #define KEY_CTRL_F1   (-1)
+  #define KEY_CTRL_F2   (-1)
+  #define KEY_CTRL_F3   (-1)
+  #define KEY_CTRL_F4   (-1)
+  #define KEY_CTRL_F5   (-1)
+  #define KEY_CTRL_F6   (-1)
+  #define KEY_CTRL_F7   (-1)
+  #define KEY_CTRL_F8   (-1)
+  #define KEY_CTRL_F9   (-1)
+  #define KEY_CTRL_F10  (-1)
+
+  #define KEY_ALT_F1    (-1)
+  #define KEY_ALT_F2    (-1)
+  #define KEY_ALT_F3    (-1)
+  #define KEY_ALT_F4    (-1)
+  #define KEY_ALT_F5    (-1)
+  #define KEY_ALT_F6    (-1)
+  #define KEY_ALT_F7    (-1)
+  #define KEY_ALT_F8    (-1)
+  #define KEY_ALT_F9    (-1)
+  #define KEY_ALT_F10   (-1)
+
+  #define KEY_RESIZE    YAS_SCREEN_SIZE
+#else
+
+  #error One of ncurses/yascreen libraries is required under UNIX
+
 #endif
 
 /******* common (part 2) ***************************************************/
@@ -326,6 +449,7 @@
 
   void con_suspend(); // suspends console (before system() for example)
   void con_restore(); // restores console after suspend
+  void con_reset_screen_size(); // reset screen info on screen resize, called in SIGWINCH
 
   void con_ce( int attr = -1 ); // clear to end-of-line
   void con_cs( int attr = -1 ); // clear screen
